@@ -17,7 +17,7 @@
 use rand::{thread_rng, Rng};
 
 use snarkvm_algorithms::{
-    crh::{BoweHopwoodPedersenCRH, BoweHopwoodPedersenCompressedCRH, PedersenCRH, PedersenCompressedCRH, PedersenSize},
+    crh::{BoweHopwoodPedersenCRH, BoweHopwoodPedersenCompressedCRH, PedersenCRH, PedersenCompressedCRH},
     traits::{CRHParameters, CRH},
 };
 use snarkvm_curves::{
@@ -34,7 +34,7 @@ use crate::{
         PedersenCRHGadget,
         PedersenCompressedCRHGadget,
     },
-    curves::edwards_bls12::EdwardsBlsGadget,
+    curves::edwards_bls12::EdwardsBls12Gadget,
     integers::uint::UInt8,
     traits::{
         algorithms::{CRHGadget, MaskedCRHGadget},
@@ -43,21 +43,11 @@ use crate::{
     },
 };
 
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub(super) struct Size;
+const PEDERSEN_NUM_WINDOWS: usize = 8;
+const PEDERSEN_WINDOW_SIZE: usize = 128;
 
-impl PedersenSize for Size {
-    const NUM_WINDOWS: usize = 8;
-    const WINDOW_SIZE: usize = 128;
-}
-
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub(super) struct BoweHopwoodSize;
-
-impl PedersenSize for BoweHopwoodSize {
-    const NUM_WINDOWS: usize = 32;
-    const WINDOW_SIZE: usize = 48;
-}
+const BHP_NUM_WINDOWS: usize = 32;
+const BHP_WINDOW_SIZE: usize = 48;
 
 const PEDERSEN_HASH_CONSTRAINTS: usize = 5632;
 const PEDERSEN_HASH_CONSTRAINTS_ON_AFFINE: usize = 6656;
@@ -172,8 +162,8 @@ fn masked_crh_gadget_test<F: PrimeField, H: CRH, CG: MaskedCRHGadget<H, F>>() {
 mod pedersen_crh_gadget_on_projective {
     use super::*;
 
-    type TestCRH = PedersenCRH<EdwardsProjective, Size>;
-    type TestCRHGadget = PedersenCRHGadget<EdwardsProjective, Fr, EdwardsBlsGadget>;
+    type TestCRH = PedersenCRH<EdwardsProjective, PEDERSEN_NUM_WINDOWS, PEDERSEN_WINDOW_SIZE>;
+    type TestCRHGadget = PedersenCRHGadget<EdwardsProjective, Fr, EdwardsBls12Gadget>;
 
     #[test]
     fn primitive_gadget_test() {
@@ -189,8 +179,8 @@ mod pedersen_crh_gadget_on_projective {
 mod pedersen_crh_gadget_on_affine {
     use super::*;
 
-    type TestCRH = PedersenCRH<EdwardsAffine, Size>;
-    type TestCRHGadget = PedersenCRHGadget<EdwardsAffine, Fr, EdwardsBlsGadget>;
+    type TestCRH = PedersenCRH<EdwardsAffine, PEDERSEN_NUM_WINDOWS, PEDERSEN_WINDOW_SIZE>;
+    type TestCRHGadget = PedersenCRHGadget<EdwardsAffine, Fr, EdwardsBls12Gadget>;
 
     #[test]
     fn primitive_gadget_test() {
@@ -201,8 +191,8 @@ mod pedersen_crh_gadget_on_affine {
 mod pedersen_compressed_crh_gadget_on_projective {
     use super::*;
 
-    type TestCRH = PedersenCompressedCRH<EdwardsProjective, Size>;
-    type TestCRHGadget = PedersenCompressedCRHGadget<EdwardsProjective, Fr, EdwardsBlsGadget>;
+    type TestCRH = PedersenCompressedCRH<EdwardsProjective, PEDERSEN_NUM_WINDOWS, PEDERSEN_WINDOW_SIZE>;
+    type TestCRHGadget = PedersenCompressedCRHGadget<EdwardsProjective, Fr, EdwardsBls12Gadget>;
 
     #[test]
     fn primitive_gadget_test() {
@@ -220,8 +210,8 @@ mod pedersen_compressed_crh_gadget_on_projective {
 mod bowe_hopwood_pedersen_crh_gadget_on_projective {
     use super::*;
 
-    type TestCRH = BoweHopwoodPedersenCRH<EdwardsProjective, BoweHopwoodSize>;
-    type TestCRHGadget = BoweHopwoodPedersenCRHGadget<EdwardsProjective, Fr, EdwardsBlsGadget>;
+    type TestCRH = BoweHopwoodPedersenCRH<EdwardsProjective, BHP_NUM_WINDOWS, BHP_WINDOW_SIZE>;
+    type TestCRHGadget = BoweHopwoodPedersenCRHGadget<EdwardsProjective, Fr, EdwardsBls12Gadget>;
 
     #[test]
     fn primitive_gadget_test() {
@@ -232,8 +222,8 @@ mod bowe_hopwood_pedersen_crh_gadget_on_projective {
 mod bowe_hopwood_pedersen_compressed_crh_gadget_on_projective {
     use super::*;
 
-    type TestCRH = BoweHopwoodPedersenCompressedCRH<EdwardsProjective, BoweHopwoodSize>;
-    type TestCRHGadget = BoweHopwoodPedersenCompressedCRHGadget<EdwardsProjective, Fr, EdwardsBlsGadget>;
+    type TestCRH = BoweHopwoodPedersenCompressedCRH<EdwardsProjective, BHP_NUM_WINDOWS, BHP_WINDOW_SIZE>;
+    type TestCRHGadget = BoweHopwoodPedersenCompressedCRHGadget<EdwardsProjective, Fr, EdwardsBls12Gadget>;
 
     #[test]
     fn primitive_gadget_test() {
