@@ -840,7 +840,17 @@ impl<F: Field> AllocGadget<bool, F> for Boolean {
     }
 }
 
-impl<F: Field> EqGadget<F> for Boolean {}
+impl<F: Field> EqGadget<F> for Boolean {
+    fn is_eq<CS: ConstraintSystem<F>>(&self, mut cs: CS, other: &Self) -> Result<Boolean, SynthesisError> {
+        // self | other | XNOR(self, other) | self == other
+        // -----|-------|-------------------|--------------
+        //   0  |   0   |         1         |      1
+        //   0  |   1   |         0         |      0
+        //   1  |   0   |         0         |      0
+        //   1  |   1   |         1         |      1
+        Ok(self.xor(cs.ns(|| "xor"), other)?.not())
+    }
+}
 
 impl<F: Field> ConditionalEqGadget<F> for Boolean {
     fn conditional_enforce_equal<CS: ConstraintSystem<F>>(
