@@ -14,8 +14,6 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use snarkvm_curves::bls12_377::{Bls12_377Parameters, Fq, Fq12Parameters, Fq2Parameters, Fq6Parameters};
-
 use crate::{
     curves::templates::bls12::{
         Bls12PairingGadget,
@@ -26,6 +24,7 @@ use crate::{
     },
     fields::{Fp12Gadget, Fp2Gadget, Fp6Gadget, FpGadget},
 };
+use snarkvm_curves::bls12_377::{Bls12_377Parameters, Fq, Fq12Parameters, Fq2Parameters, Fq6Parameters};
 
 pub type FqGadget = FpGadget<Fq>;
 pub type Fq2Gadget = Fp2Gadget<Fq2Parameters, Fq>;
@@ -39,20 +38,7 @@ pub type PairingGadget = Bls12PairingGadget<Bls12_377Parameters>;
 
 #[cfg(test)]
 mod test {
-    use rand::{
-        SeedableRng,
-        {self},
-    };
-    use rand_xorshift::XorShiftRng;
-
-    use snarkvm_curves::{
-        bls12_377::{Fq, Fr, G1Projective as G1, G2Projective as G2},
-        traits::{AffineCurve, ProjectiveCurve},
-    };
-    use snarkvm_fields::PrimeField;
-    use snarkvm_r1cs::{ConstraintSystem, TestConstraintSystem};
-    use snarkvm_utilities::{bititerator::BitIteratorBE, rand::UniformRand};
-
+    use super::*;
     use crate::{
         bits::boolean::{AllocatedBit, Boolean},
         traits::{
@@ -63,8 +49,21 @@ mod test {
             select::CondSelectGadget,
         },
     };
+    use snarkvm_curves::{
+        bls12_377::{Fq, Fr, G1Projective as G1, G2Projective as G2},
+        traits::ProjectiveCurve,
+        Group,
+    };
+    use snarkvm_fields::PrimeField;
+    use snarkvm_r1cs::{ConstraintSystem, TestConstraintSystem};
+    use snarkvm_utilities::{bititerator::BitIteratorBE, rand::UniformRand};
 
-    use super::*;
+    use core::ops::Mul;
+    use rand::{
+        SeedableRng,
+        {self},
+    };
+    use rand_xorshift::XorShiftRng;
 
     #[test]
     fn bls12_g1_constraint_costs() {
@@ -128,7 +127,7 @@ mod test {
         assert_eq!(gadget_b.y.get_value().unwrap(), b_affine.y);
 
         // Check addition
-        let ab = a + &b;
+        let ab = a + b;
         let ab_affine = ab.into_affine();
         let gadget_ab = gadget_a.add(&mut cs.ns(|| "ab"), &gadget_b).unwrap();
         let gadget_ba = gadget_b.add(&mut cs.ns(|| "ba"), &gadget_a).unwrap();
@@ -154,7 +153,7 @@ mod test {
 
         // Check mul_bits
         let scalar = Fr::rand(&mut rng);
-        let native_result = aa.into_affine().mul(scalar) + &b;
+        let native_result = aa.mul(scalar) + b;
         let native_result = native_result.into_affine();
 
         let mut scalar: Vec<bool> = BitIteratorBE::new(scalar.into_repr()).collect();
@@ -193,7 +192,7 @@ mod test {
         assert_eq!(gadget_b.x.get_value().unwrap(), b_affine.x);
         assert_eq!(gadget_b.y.get_value().unwrap(), b_affine.y);
 
-        let ab = a + &b;
+        let ab = a + b;
         let ab_affine = ab.into_affine();
         let gadget_ab = gadget_a.add(&mut cs.ns(|| "ab"), &gadget_b).unwrap();
         let gadget_ba = gadget_b.add(&mut cs.ns(|| "ba"), &gadget_a).unwrap();
