@@ -14,17 +14,10 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use snarkvm_curves::{
-    edwards_bls12::{EdwardsProjective, Fq},
-    traits::Group,
-};
+use crate::traits::GroupGadget;
+use snarkvm_curves::traits::Group;
 use snarkvm_fields::Field;
-use snarkvm_r1cs::{ConstraintSystem, TestConstraintSystem};
-
-use crate::{
-    curves::edwards_bls12::EdwardsBlsGadget,
-    traits::{alloc::AllocGadget, curves::GroupGadget},
-};
+use snarkvm_r1cs::ConstraintSystem;
 
 #[allow(clippy::eq_op)]
 pub fn group_test<F: Field, G: Group, GG: GroupGadget<G, F>, CS: ConstraintSystem<F>>(cs: &mut CS, a: GG, b: GG) {
@@ -44,8 +37,8 @@ pub fn group_test<F: Field, G: Group, GG: GroupGadget<G, F>, CS: ConstraintSyste
     let b_a = b.add(cs.ns(|| "b_plus_a"), &a).unwrap();
     assert_eq!(a_b, b_a);
     // (a + b) + a = a + (b + a)
-    let ab_a = a_b.add(&mut cs.ns(|| "a_b_plus_a"), &a).unwrap();
-    let a_ba = a.add(&mut cs.ns(|| "a_plus_b_a"), &b_a).unwrap();
+    let ab_a = a_b.add(&mut cs.ns(|| "(a + b) + a"), &a).unwrap();
+    let a_ba = a.add(&mut cs.ns(|| "a + (b + a)"), &b_a).unwrap();
     assert_eq!(ab_a, a_ba);
     // a.double() = a + a
     let a_a = a.add(cs.ns(|| "a + a"), &a).unwrap();
@@ -64,15 +57,3 @@ pub fn group_test<F: Field, G: Group, GG: GroupGadget<G, F>, CS: ConstraintSyste
     let _ = b.to_bytes(&mut cs.ns(|| "b ToBytes")).unwrap();
     let _ = b.to_bytes_strict(&mut cs.ns(|| "b ToBytes Strict")).unwrap();
 }
-
-#[test]
-fn edwards_bls12_group_gadgets_test() {
-    let mut cs = TestConstraintSystem::<Fq>::new();
-
-    let a: EdwardsProjective = rand::random();
-    let b: EdwardsProjective = rand::random();
-
-    let a = EdwardsBlsGadget::alloc(&mut cs.ns(|| "generate_a"), || Ok(a)).unwrap();
-    let b = EdwardsBlsGadget::alloc(&mut cs.ns(|| "generate_b"), || Ok(b)).unwrap();
-    group_test::<_, EdwardsProjective, _, _>(&mut cs.ns(|| "GroupTest(a, b)"), a, b);
-}
