@@ -14,7 +14,7 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use snarkvm_algorithms::traits::SignatureScheme;
+use snarkvm_algorithms::{prf::Blake2s, traits::SignatureScheme};
 use snarkvm_fields::Field;
 use snarkvm_r1cs::{errors::SynthesisError, ConstraintSystem};
 
@@ -22,11 +22,14 @@ use crate::{
     bits::ToBytesGadget,
     integers::uint::UInt8,
     traits::{alloc::AllocGadget, eq::EqGadget},
+    Boolean,
+    PRFGadget,
 };
 
 pub trait SignaturePublicKeyRandomizationGadget<S: SignatureScheme, F: Field> {
     type ParametersGadget: AllocGadget<S::Parameters, F>;
     type PublicKeyGadget: ToBytesGadget<F> + EqGadget<F> + AllocGadget<S::PublicKey, F> + Clone;
+    type SignatureGadget: ToBytesGadget<F> + EqGadget<F> + AllocGadget<S::Signature, F> + Clone;
 
     fn check_randomization_gadget<CS: ConstraintSystem<F>>(
         cs: CS,
@@ -34,4 +37,12 @@ pub trait SignaturePublicKeyRandomizationGadget<S: SignatureScheme, F: Field> {
         public_key: &Self::PublicKeyGadget,
         randomness: &[UInt8],
     ) -> Result<Self::PublicKeyGadget, SynthesisError>;
+
+    fn verify<CS: ConstraintSystem<F>, PG: PRFGadget<Blake2s, F>>(
+        cs: CS,
+        parameters: &Self::ParametersGadget,
+        public_key: &Self::PublicKeyGadget,
+        message: &[UInt8],
+        signature: &Self::SignatureGadget,
+    ) -> Result<Boolean, SynthesisError>;
 }
